Struct rend3_types::RawResourceHandle [−][src]
pub struct RawResourceHandle<T> {
pub idx: usize,
// some fields omitted
}Expand description
Non-owning resource handle. Not part of rend3’s external interface, but needed to interface with rend3’s internal datastructures if writing your own structures or render routines.
Fields
idx: usizeTrait Implementations